c======================================================================|
c     array definitions
c======================================================================|
      implicit real*8 (a-h,o-z)
      parameter (ix=1007)

      dimension x(ix),xm(ix)
      dimension dx(ix),dxm(ix)

      dimension ro(ix),pr(ix)
      dimension vx(ix)

      dimension sc(ix),scm(ix)
      dimension dsc(ix),dscm(ix)

c                                                      hdcip - start >>>
      dimension te(ix),vxm(ix),rodx(ix),tedx(ix),vxdxm(ix)
c                                                      hdcip - end   <<<

c======================================================================|
c     prologue
c======================================================================|

c----------------------------------------------------------------------|
c   parameters
c   margin: 1 in MLW, 2 in Roe, 4 in CIP

      margin=4

c----------------------------------------------------------------------|
c  file open
c                                                     netcdf - start >>>
      call ncopn1d(idf,'out.cdf',idn,idi,ix)
      call ncputattc(idf,'comment','cans1d md_sedov')
      call ncdefss(idf,'t',idt,idn)
      call ncdefs1(idf,'ro',idro,idn,idi)
      call ncdefs1(idf,'pr',idpr,idn,idi)
      call ncdefs1(idf,'vx',idvx,idn,idi)
c                                                     netcdf - end   <<<

c----------------------------------------------------------------------|
c  initialize counters

      nd=1
      time  = 0.0
      timep = 0.0
      ns    = 0
      merr  = 0

c----------------------------------------------------------------------|
c   time control parameters
c     nstop : number of total time steps for the run

      tend=3.0
      dtout=0.1
      nstop=1000000

c----------------------------------------------------------------------|
c   setup numerical model (grid, initial conditions, etc.)

      call model(idf,ro,pr,vx,gm,sc,scm,margin,x,ix)
      call bnd(margin,ro,pr,vx,ix)
      floor=1.d-9
      call chkdav(n_floor,ro,vx,floor,ix)
      call chkdav(n_floor,pr,vx,floor,ix)

c----------------------------------------------------------------------|
c     ready

      call grdrdy(dx,xm,dxm,x,ix)
      call scrdy(dsc,dscm,sc,scm,dx,dxm,ix)
      call bndsc(margin,sc,dsc,scm,dscm,ix)

c                                                      hdcip - start >>>
      call ciprdy_h(te,vxm,rodx,tedx,vxdxm,ro,pr,vx,gm,dx,dxm,ix)
      call cipbnd(margin,ro,te,vxm,rodx,tedx,vxdxm,ix)
c                                                      hdcip - end   <<<

c----------------------------------------------------------------------|
c     data output
c                                                     netcdf - start >>>
      call ncputo1(idf,idi,'x',x,ix)
      call ncputosi(idf,'margin',margin)
      call ncputos(idf,'gm',gm)
      call ncputo1(idf,idi,'sc',sc,ix)
      call ncputo1(idf,idi,'scm',scm,ix)

      call ncputss(idf,idt,nd,time)
      call ncputs1(idf,idro,nd,ro,ix)
      call ncputs1(idf,idpr,nd,pr,ix)
      call ncputs1(idf,idvx,nd,vx,ix)
            mstatus=nf_sync(idf)
c                                                     netcdf - end   <<<
      write(6,913) ns,time,nd
      nd=nd+1

c======================================================================|
c     time integration start  
c======================================================================|
1000  continue  
         ns = ns+1
         mwflag=0

c----------------------------------------------------------------------|
c     obtain time spacing

         call cfl_h(dt,merr,gm,ro,pr,vx,dx,ix)
         if (merr.ne.0) goto 9999
         timep = time
         time = time+dt

c----------------------------------------------------------------------|
c     solve hydrodynamic equations

c                                                      hdmlw - start >>>
         call mlw_h_c(ro,pr,vx,dt,gm,sc,dsc,scm,dscm,dx,dxm,ix)
c                                                      hdmlw - end   <<<
c                                                      hdroe - start >>>
c        call roe_h_c(ro,pr,vx,dt,gm,sc,dsc,scm,dx,ix)
c                                                      hdroe - end   <<<
c                                                      hdcip - start >>>
c        call cip_h_c(ro,pr,vx,te,vxm,rodx,tedx,vxdxm
c    &         ,dt,gm,sc,scm,dx,dxm,ix)
c                                                      hdcip - end   <<<

         call bnd(margin,ro,pr,vx,ix)
         floor=1.d-9
         call chkdav(n_floor,ro,vx,floor,ix)
         call chkdav(n_floor,pr,vx,floor,ix)

c                                                      hdcip - start >>>
         call cipbnd(margin,ro,te,vxm,rodx,tedx,vxdxm,ix)
c                                                      hdcip - end   <<<

c----------------------------------------------------------------------|
c     data output

         mw=0
         nt1=int(timep/dtout)
         nt2=int(time/dtout)
         if (nt1.lt.nt2) mw=1
         if (mw.ne.0) then
            write(6,913) ns,time,nd
c                                                     netcdf - start >>>
            call ncputss(idf,idt,nd,time)
            call ncputs1(idf,idro,nd,ro,ix)
            call ncputs1(idf,idpr,nd,pr,ix)
            call ncputs1(idf,idvx,nd,vx,ix)
            mstatus=nf_sync(idf)
c                                                     netcdf - end   <<<
            nd=nd+1
            mwflag=1
         endif

c----------------------------------------------------------------------|
c     loop test

      if (ns .lt. nstop .and. time .lt. tend) goto 1000
         
c======================================================================|
c     epilogue
c======================================================================|
9999  continue

c----------------------------------------------------------------------|
c  data output
      if (mwflag.eq.0) then
            write(6,913) ns,time,nd
c                                                     netcdf - start >>>
            call ncputss(idf,idt,nd,time)
            call ncputs1(idf,idro,nd,ro,ix)
            call ncputs1(idf,idpr,nd,pr,ix)
            call ncputs1(idf,idvx,nd,vx,ix)
            mstatus=nf_sync(idf)
c                                                     netcdf - end   <<<
      endif

c----------------------------------------------------------------------|
c  file close
c                                                     netcdf - start >>>
      mstatus=nf_close(idf)
c                                                     netcdf - end   <<<

c----------------------------------------------------------------------|
c  ending message

      write(6,915) ns,time
      if (merr.eq.0) then
        write(6,*) '  ### normal stop ###'
      else
        write(6,*) '  ### abnormal stop ###'
      endif 

      stop

913   format (1x,' write    ','step=',i8,' time=',e10.3,' nd =',i3)
915   format (1x,' stop     ','step=',i8,' time=',e10.3)
c
      end
