c======================================================================|
c     array definitions
c======================================================================|
      implicit real*8 (a-h,o-z)
      parameter (ix=53,jx=203)

      dimension x(ix),xm(ix)
      dimension dx(ix),dxm(ix)
      dimension z(jx),zm(jx)
      dimension dz(jx),dzm(jx)

      dimension ro(ix,jx),pr(ix,jx)
      dimension vx(ix,jx),vz(ix,jx)


c======================================================================|
c     prologue
c======================================================================|

c----------------------------------------------------------------------|
c   parameters
c   margin: 1 in MLW, 2 in Roe, 4 in CIP

      margin=2

c----------------------------------------------------------------------|
c  file open
c                                                     netcdf - start >>>
      call ncopn2d(idf,'out.cdf',idn,idi,ix,idj,jx)
      call ncputattc(idf,'comment','cans2d md_jetprop')
      call ncputosi(idf,'margin',margin)
      call ncdefss(idf,'t',idt,idn)
      call ncdefs2(idf,'ro',idro,idn,idi,idj)
      call ncdefs2(idf,'pr',idpr,idn,idi,idj)
      call ncdefs2(idf,'vx',idvx,idn,idi,idj)
      call ncdefs2(idf,'vz',idvz,idn,idi,idj)
c                                                     netcdf - end   <<<

c----------------------------------------------------------------------|
c  initialize counters

      nd=1
      time  = 0.0
      timep = 0.0
      ns    = 0
      merr  = 0

c----------------------------------------------------------------------|
c   time control parameters
c     nstop : number of total time steps for the run

      tend=5.0
      dtout=0.2
      nstop=1000000
c     tend=3.0

c----------------------------------------------------------------------|
c   setup numerical model (grid, initial conditions, etc.)

      call model(idf,ro,pr,vx,vz,gm,margin,x,ix,z,jx)

c----------------------------------------------------------------------|
c     ready

      call grdrdy(dx,xm,dxm,x,ix)
      call grdrdy(dz,zm,dzm,z,jx)


c----------------------------------------------------------------------|
c     data output 
c                                                     netcdf - start >>>
      call ncputo1(idf,idi,'x',x,ix)
      call ncputo1(idf,idj,'z',z,jx)
      call ncputosi(idf,'margin',margin)

      call ncputss(idf,idt,nd,time)
      call ncputs2(idf,idro,nd,ro,ix,jx)
      call ncputs2(idf,idpr,nd,pr,ix,jx)
      call ncputs2(idf,idvx,nd,vx,ix,jx)
      call ncputs2(idf,idvz,nd,vz,ix,jx)
      mstatus=nf_sync(idf)
c                                                     netcdf - end   <<<
      write(6,913) ns,time,nd
      nd=nd+1

c======================================================================|
c     time integration 
c======================================================================|
1000  continue  
         ns = ns+1
         mwflag=0

c----------------------------------------------------------------------|
c     obtain time spacing

         call cfl_h(dt,merr,gm,ro,pr,vx,vz,dx,ix,dz,jx)
         if (merr.ne.0) goto 9999
         timep = time
         time = time+dt

c----------------------------------------------------------------------|
c     solve hydrodynamic equations

c                                                      hdmlw - start >>>
         call mlw_h_c(ro,pr,vx,vz,dt,gm,x,xm,dx,dxm,ix,dz,dzm,jx)
c                                                      hdmlw - end   <<<
c                                                      hdroe - start >>>
c        call roe_h_c(ro,pr,vx,vz,dt,gm,x,dx,ix,dz,jx)
c                                                      hdroe - end   <<<

         call bnd(margin,ro,pr,vx,vz,gm,x,ix,jx)
         floor=1.d-9
         call chkdav(n_floor,ro,vx,vz,floor,ix,jx)
         call chkdav(n_floor,pr,vx,vz,floor,ix,jx)


c----------------------------------------------------------------------|
c     data output 

         mw=0
         nt1=int(timep/dtout)
         nt2=int(time/dtout)
         if (nt1.lt.nt2) mw=1
         if (mw.ne.0) then
c                                                     netcdf - start >>>
            call ncputss(idf,idt,nd,time)
            call ncputs2(idf,idro,nd,ro,ix,jx)
            call ncputs2(idf,idpr,nd,pr,ix,jx)
            call ncputs2(idf,idvx,nd,vx,ix,jx)
            call ncputs2(idf,idvz,nd,vz,ix,jx)
            mstatus=nf_sync(idf)
c                                                     netcdf - end   <<<
            write(6,913) ns,time,nd
            nd=nd+1
            mwflag=1
         endif

c----------------------------------------------------------------------|
c     loop test

      if (ns .lt. nstop .and. time .lt. tend) goto 1000
c======================================================================|
c     epilogue
c======================================================================|
9999  continue

c----------------------------------------------------------------------|
c  data output
      if (mwflag.eq.0) then
            write(6,913) ns,time,nd
c                                                     netcdf - start >>>
            call ncputss(idf,idt,nd,time)
            call ncputs2(idf,idro,nd,ro,ix,jx)
            call ncputs2(idf,idpr,nd,pr,ix,jx)
            call ncputs2(idf,idvx,nd,vx,ix,jx)
            call ncputs2(idf,idvz,nd,vz,ix,jx)
            mstatus=nf_sync(idf)
c                                                     netcdf - end   <<<
      endif

c----------------------------------------------------------------------|
c  file close
c                                                     netcdf - start >>>
      mstatus=nf_close(idf)
c                                                     netcdf - end   <<<


c----------------------------------------------------------------------|
c  ending message

      write(6,915) ns,time
      if (merr.eq.0) then
        write(6,*) '  ### normal stop ###'
      else
        write(6,*) '  ### abnormal stop ###'
      endif 

      stop

913   format (1x,' write    ','step=',i8,' time=',e10.3,' nd =',i3)
915   format (1x,' stop     ','step=',i8,' time=',e10.3)

      end
